@@ -78,6 +78,10 @@ BaseJob::~BaseJob()
 
 void BaseJob::dataFinished()
 {
+    if (!d->m_reply) {
+        return;
+    }
+
     bool error = (d->m_reply->error() != QNetworkReply::NoError);
 
     // handle redirections automatically
@@ -100,7 +104,7 @@ void BaseJob::dataFinished()
 
     if (!error) {
         QByteArray data = d->m_reply->readAll();
-        //qDebug() << data;
+        qDebug() << "XML Returned:\n" << data;
         parse(QString::fromUtf8(data.constData()));
         if (d->m_metadata.statusCode() == 100) {
             d->m_metadata.setError(Metadata::NoError);
