@@ -2,6 +2,7 @@
     This file is part of KDE.
 
     Copyright (c) 2008 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (c) 2010 Sebastian Kügler <sebas@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,6 +28,12 @@
 #include "accountbalanceparser.h"
 #include "activity.h"
 #include "activityparser.h"
+#include "buildservice.h"
+#include "buildserviceparser.h"
+#include "buildservicejob.h"
+#include "buildservicejobparser.h"
+#include "buildservicejoboutput.h"
+#include "buildservicejoboutputparser.h"
 #include "privatedata.h"
 #include "privatedataparser.h"
 #include "category.h"
@@ -56,6 +63,14 @@
 #include "platformdependent.h"
 #include "postjob.h"
 #include "postfiledata.h"
+#include "project.h"
+#include "projectparser.h"
+#include "publisher.h"
+#include "publisherparser.h"
+#include "publisherfield.h"
+#include "publisherfieldparser.h"
+#include "remoteaccount.h"
+#include "remoteaccountparser.h"
 #include "itemjob.h"
 #include "listjob.h"
 
@@ -181,11 +196,19 @@ bool Provider::isValid() const
 
 bool Provider::isEnabled() const
 {
+    if (!isValid()) {
+        return false;
+    }
+
     return d->m_internals->isEnabled(d->m_baseUrl);
 }
 
 void Provider::setEnabled(bool enabled)
 {
+    if (!isValid()) {
+        return;
+    }
+
     d->m_internals->enableProvider(d->m_baseUrl, enabled);
 }
 
@@ -196,16 +219,28 @@ QString Provider::name() const
 
 bool Provider::hasCredentials()
 {
+    if (!isValid()) {
+        return false;
+    }
+
     return d->m_internals->hasCredentials(d->m_baseUrl);
 }
 
 bool Provider::hasCredentials() const
 {
+    if (!isValid()) {
+        return false;
+    }
+
     return d->m_internals->hasCredentials(d->m_baseUrl);
 }
 
 bool Provider::loadCredentials(QString& user, QString& password)
 {
+    if (!isValid()) {
+        return false;
+    }
+
     if (d->m_internals->loadCredentials(d->m_baseUrl, user, password)) {
         d->m_credentialsUserName = user;
         d->m_credentialsPassword = password;
@@ -216,6 +251,10 @@ bool Provider::loadCredentials(QString& user, QString& password)
 
 bool Provider::saveCredentials(const QString& user, const QString& password)
 {
+    if (!isValid()) {
+        return false;
+    }
+
     d->m_credentialsUserName = user;
     d->m_credentialsPassword = password;
     return d->m_internals->saveCredentials(d->m_baseUrl, user, password);
@@ -223,6 +262,10 @@ bool Provider::saveCredentials(const QString& user, const QString& password)
 
 PostJob* Provider::checkLogin(const QString& user, const QString& password)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QMap<QString, QString> postParameters;
 
     postParameters.insert(QLatin1String( "login" ), user);
@@ -233,6 +276,10 @@ PostJob* Provider::checkLogin(const QString& user, const QString& password)
 
 PostJob* Provider::registerAccount(const QString& id, const QString& password, const QString& mail, const QString& firstName, const QString& lastName)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QMap<QString, QString> postParameters;
 
     postParameters.insert(QLatin1String( "login" ), id);
@@ -247,24 +294,40 @@ PostJob* Provider::registerAccount(const QString& id, const QString& password, c
 
 ItemJob<Person>* Provider::requestPerson(const QString& id)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "person/data/" ) + id );
     return doRequestPerson( url );
 }
 
 ItemJob<Person>* Provider::requestPersonSelf()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "person/self" ) );
     return doRequestPerson( url );
 }
 
 ItemJob<AccountBalance>* Provider::requestAccountBalance()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "person/balance" ) );
     return doRequestAccountBalance( url );
 }
 
 ListJob<Person>* Provider::requestPersonSearchByName(const QString& name)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "person/data" ));
     url.addQueryItem(QLatin1String( "name" ), name);
     return doRequestPersonList( url );
@@ -272,6 +335,10 @@ ListJob<Person>* Provider::requestPersonSearchByName(const QString& name)
 
 ListJob<Person>* Provider::requestPersonSearchByLocation(qreal latitude, qreal longitude, qreal distance, int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "person/data" ) );
     url.addQueryItem(QLatin1String( "latitude" ), QString::number(latitude));
     url.addQueryItem(QLatin1String( "longitude" ), QString::number(longitude));
@@ -286,6 +353,10 @@ ListJob<Person>* Provider::requestPersonSearchByLocation(qreal latitude, qreal l
 
 ListJob<Person>* Provider::requestFriends(const QString& id, int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "friend/data/" ) + id );
     url.addQueryItem(QLatin1String( "page" ), QString::number(page));
     url.addQueryItem(QLatin1String( "pagesize" ), QString::number(pageSize));
@@ -295,6 +366,10 @@ ListJob<Person>* Provider::requestFriends(const QString& id, int page, int pageS
 
 ListJob<Person>* Provider::requestSentInvitations(int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "friend/sentinvitations" ));
     url.addQueryItem(QLatin1String( "page" ), QString::number(page));
     url.addQueryItem(QLatin1String( "pagesize" ), QString::number(pageSize));
@@ -304,6 +379,10 @@ ListJob<Person>* Provider::requestSentInvitations(int page, int pageSize)
 
 ListJob<Person>* Provider::requestReceivedInvitations(int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "friend/receivedinvitations" ));
     url.addQueryItem(QLatin1String( "page" ), QString::number(page));
     url.addQueryItem(QLatin1String( "pagesize" ), QString::number(pageSize));
@@ -313,22 +392,371 @@ ListJob<Person>* Provider::requestReceivedInvitations(int page, int pageSize)
 
 ListJob<Activity>* Provider::requestActivities()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     qDebug() << "request activity";
     QUrl url = createUrl( QLatin1String( "activity" ) );
     return doRequestActivityList( url );
 }
 
 
+ListJob<Project>* Provider::requestProjects()
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    qDebug() << "request projects";
+    QUrl url = createUrl( QLatin1String("buildservice/project/list") );
+    return new ListJob<Project>(d->m_internals, createRequest(url));
+}
+
+ItemJob<Project>* Provider::requestProject(const QString& id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/project/get/") + id );
+    qDebug() << url;
+    return new ItemJob<Project>(d->m_internals, createRequest(url));
+}
+
+QMap<QString, QString> projectPostParameters(const Project& project)
+{
+    QMap<QString, QString> postParameters;
+
+    if (!project.name().isEmpty()) {
+        postParameters.insert(QLatin1String("name"), project.name());
+    }
+    if (!project.summary().isEmpty()) {
+        postParameters.insert(QLatin1String("summary"), project.summary());
+    }
+    if (!project.description().isEmpty()) {
+        postParameters.insert(QLatin1String("description"), project.description());
+    }
+    if (!project.url().isEmpty()) {
+        postParameters.insert(QLatin1String("url"), project.url());
+    }
+    if (project.developers().count()) {
+        postParameters.insert(QLatin1String("developers"), project.developers().join(QLatin1String("\n")));
+    }
+    if (!project.version().isEmpty()) {
+        postParameters.insert(QLatin1String("version"), project.version());
+    }
+    if (!project.license().isEmpty()) {
+        postParameters.insert(QLatin1String("license"), project.license());
+    }
+    if (!project.requirements().isEmpty()) {
+        postParameters.insert(QLatin1String("requirements"), project.requirements());
+    }
+    // The specfile generator expects an empty string parameter if it is supposed to regenerate the spec file
+    // So we need to check for nullity here as opposed to an empty string.
+    if (!project.specFile().isNull()) {
+        postParameters.insert(QLatin1String("specfile"), project.specFile());
+    }
+    return postParameters;
+}
+
+PostJob* Provider::createProject(const Project& project)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/project/create")),
+                       projectPostParameters(project));
+}
+
+PostJob* Provider::editProject(const Project& project)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    return new PostJob(d->m_internals, createRequest(
+                       QLatin1String("buildservice/project/edit/") + project.id()),
+                       projectPostParameters(project));
+}
+
+PostJob* Provider::deleteProject(const Project& project)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    return new PostJob(d->m_internals, createRequest(
+                       QLatin1String("buildservice/project/delete/") + project.id()),
+                       projectPostParameters(project));
+}
+
+ItemJob<BuildService>* Provider::requestBuildService(const QString& id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/buildservices/get/") + id );
+    return new ItemJob<BuildService>(d->m_internals, createRequest(url));
+}
+
+ItemJob<Publisher>* Provider::requestPublisher(const QString& id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    //qDebug() << "request publisher" << id;
+    QUrl url = createUrl( QLatin1String("buildservice/publishing/getpublisher/") + id );
+    return new ItemJob<Publisher>(d->m_internals, createRequest(url));
+}
+
+PostJob* Provider::savePublisherField(const Project& project, const PublisherField& field)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    postParameters.insert(QLatin1String("fields[0][name]"), field.name());
+    postParameters.insert(QLatin1String("fields[0][fieldtype]"), field.type());
+    postParameters.insert(QLatin1String("fields[0][data]"), field.data());
+
+    QString url = QLatin1String("buildservice/publishing/savefields/") + project.id();
+    //qDebug() << "saving field values...";
+    return new PostJob(d->m_internals, createRequest(url), postParameters);
+}
+
+PostJob* Provider::publishBuildJob(const BuildServiceJob& buildjob, const Publisher& publisher)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
+
+    QString url = QLatin1String("buildservice/publishing/publishtargetresult/") + 
+                                                                    buildjob.id() + QLatin1Char('/') + publisher.id();
+    //qDebug() << "pub'ing";
+    return new PostJob(d->m_internals, createRequest(url), postParameters);
+}
+
+// Buildservices and their jobs
+ItemJob<BuildServiceJobOutput>* Provider::requestBuildServiceJobOutput(const QString &id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/jobs/getoutput/") + id );
+    qDebug() << url;
+    return new ItemJob<BuildServiceJobOutput>(d->m_internals, createRequest(url));
+}
+
+ItemJob<BuildServiceJob>* Provider::requestBuildServiceJob(const QString &id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/jobs/get/") + id );
+    qDebug() << url;
+    return new ItemJob<BuildServiceJob>(d->m_internals, createRequest(url));
+}
+
+QMap<QString, QString> buildServiceJobPostParameters(const BuildServiceJob& buildjob)
+{
+    QMap<QString, QString> postParameters;
+
+    if (!buildjob.name().isEmpty()) {
+        postParameters.insert(QLatin1String("name"), buildjob.name());
+    }
+    if (!buildjob.projectId().isEmpty()) {
+        postParameters.insert(QLatin1String("projectid"), buildjob.projectId());
+    }
+    if (!buildjob.target().isEmpty()) {
+        postParameters.insert(QLatin1String("target"), buildjob.target());
+    }
+    if (!buildjob.buildServiceId().isEmpty()) {
+        postParameters.insert(QLatin1String("buildservice"), buildjob.buildServiceId());
+    }
+
+    return postParameters;
+}
+
+PostJob* Provider::cancelBuildServiceJob(const BuildServiceJob& job)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
+    qDebug() << "b....................b";
+    return new PostJob(d->m_internals, createRequest(
+                       QLatin1String("buildservice/jobs/cancel/") + job.id()), postParameters);
+}
+
+PostJob* Provider::createBuildServiceJob(const BuildServiceJob& job)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    // A postjob won't be run without parameters. 
+    // so even while we don't need any in this case,
+    // we add dummy data to the request
+    postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
+    qDebug() << "Creating new BSJ on" << job.buildServiceId();
+    return new PostJob(d->m_internals, createRequest(
+                       QLatin1String("buildservice/jobs/create/") +
+                           job.projectId() + QLatin1Char('/') + job.buildServiceId()  + QLatin1Char('/') + job.target()),
+                       postParameters);
+}
+
+ListJob<BuildService>* Provider::requestBuildServices()
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    qDebug() << "request projects";
+    QUrl url = createUrl( QLatin1String("buildservice/buildservices/list") );
+    return new ListJob<BuildService>(d->m_internals, createRequest(url));
+}
+
+ListJob<Publisher>* Provider::requestPublishers()
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/publishing/getpublishingcapabilities") );
+    //qDebug() << "request publishers" << url;
+    return new ListJob<Publisher>(d->m_internals, createRequest(url));
+}
+
+ListJob<BuildServiceJob>* Provider::requestBuildServiceJobs(const Project &project)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    //qDebug() << "request projects";
+    QUrl url = createUrl( QLatin1String("buildservice/jobs/list/") + project.id() );
+    return new ListJob<BuildServiceJob>(d->m_internals, createRequest(url));
+}
+
+ListJob<RemoteAccount>* Provider::requestRemoteAccounts()
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    //qDebug() << "request remoteaccounts";
+    QUrl url = createUrl( QLatin1String("buildservice/remoteaccounts/list/"));
+    return new ListJob<RemoteAccount>(d->m_internals, createRequest(url));
+}
+
+PostJob* Provider::createRemoteAccount(const RemoteAccount& account)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    // A postjob won't be run without parameters.
+    // so even while we don't need any in this case,
+    // we add dummy data to the request
+    postParameters.insert(QLatin1String("login"), account.login());
+    postParameters.insert(QLatin1String("password"), account.password());
+    postParameters.insert(QLatin1String("type"), account.type());
+    postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
+    postParameters.insert(QLatin1String("data"), account.data());
+    qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/add")),
+                       postParameters);
+}
+
+PostJob* Provider::editRemoteAccount(const RemoteAccount& account)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    // A postjob won't be run without parameters.
+    // so even while we don't need any in this case,
+    // we add dummy data to the request
+    postParameters.insert(QLatin1String("login"), account.login());
+    postParameters.insert(QLatin1String("password"), account.password());
+    postParameters.insert(QLatin1String("type"), account.type());
+    postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
+    postParameters.insert(QLatin1String("data"), account.data());
+    qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/edit/") + account.id()),
+                       postParameters);
+}
+
+ItemJob<RemoteAccount>* Provider::requestRemoteAccount(const QString &id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl( QLatin1String("buildservice/remoteaccounts/get/") + id );
+    qDebug() << url;
+    return new ItemJob<RemoteAccount>(d->m_internals, createRequest(url));
+}
+
+PostJob* Provider::deleteRemoteAccount(const QString& id)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    StringMap postParameters;
+    return new PostJob(d->m_internals, createRequest(
+                       QLatin1String("buildservice/remoteaccounts/remove/") + id),
+                       postParameters);
+}
+
+PostJob* Provider::uploadTarballToBuildService(const QString& projectId, const QString& fileName, const QByteArray& payload)
+{
+    if (!isValid()) {
+        return 0;
+    }
+
+    QUrl url = createUrl(QLatin1String( "buildservice/project/uploadsource/" ) + projectId);
+    qDebug() << "Up'ing tarball" << url << projectId << fileName << payload;
+    PostFileData postRequest(url);
+    postRequest.addFile(fileName, payload, QLatin1String( "application/octet-stream" ), QLatin1String("source"));
+    return new PostJob(d->m_internals, postRequest.request(), postRequest.data());
+}
+
+// Activity
+
 PostJob* Provider::postActivity(const QString& message)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "message" ), message);
     return new PostJob(d->m_internals, createRequest(QLatin1String( "activity" )), postParameters);
 }
 
-
 PostJob* Provider::inviteFriend(const QString& to, const QString& message)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "message" ), message);
     return new PostJob(d->m_internals, createRequest(QLatin1String( "friend/invite/" ) + to), postParameters);
@@ -337,23 +765,39 @@ PostJob* Provider::inviteFriend(const QString& to, const QString& message)
 
 PostJob* Provider::approveFriendship(const QString& to)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return new PostJob(d->m_internals, createRequest(QLatin1String( "friend/approve/" ) + to));
 }
 
 
 PostJob* Provider::declineFriendship(const QString& to)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return new PostJob(d->m_internals, createRequest(QLatin1String( "friend/decline/" ) + to));
 }
 
 PostJob* Provider::cancelFriendship(const QString& to)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return new PostJob(d->m_internals, createRequest(QLatin1String( "friend/cancel/" ) + to));
 }
 
 
 PostJob* Provider::postLocation(qreal latitude, qreal longitude, const QString& city, const QString& country)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "latitude" ), QString::number(latitude));
     postParameters.insert(QLatin1String( "longitude" ), QString::number(longitude));
@@ -365,17 +809,29 @@ PostJob* Provider::postLocation(qreal latitude, qreal longitude, const QString&
 
 ListJob<Folder>* Provider::requestFolders()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return doRequestFolderList( createUrl( QLatin1String( "message" ) ) );
 }
 
 ListJob<Message>* Provider::requestMessages(const Folder& folder)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return doRequestMessageList( createUrl( QLatin1String( "message/" ) + folder.id() ) );
 }
 
 
 ListJob<Message>* Provider::requestMessages(const Folder& folder, Message::Status status)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "message/" ) + folder.id());
     url.addQueryItem(QLatin1String( "status" ), QString::number(status));
     return doRequestMessageList(url);
@@ -384,12 +840,20 @@ ListJob<Message>* Provider::requestMessages(const Folder& folder, Message::Statu
 
 ItemJob<Message>* Provider::requestMessage(const Folder& folder, const QString& id)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     return new ItemJob<Message>(d->m_internals, createRequest(QLatin1String( "message/" ) + folder.id() + QLatin1Char( '/' ) + id));
 }
 
 
 PostJob* Provider::postMessage( const Message &message )
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "message" ), message.body());
     postParameters.insert(QLatin1String( "subject" ), message.subject());
@@ -399,6 +863,10 @@ PostJob* Provider::postMessage( const Message &message )
 
 ListJob<Category>* Provider::requestCategories()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/categories" ) );
     ListJob<Category> *job = new ListJob<Category>(d->m_internals, createRequest(url));
     return job;
@@ -406,6 +874,10 @@ ListJob<Category>* Provider::requestCategories()
 
 ListJob< License >* Provider::requestLicenses()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/licenses" ) );
     ListJob<License> *job = new ListJob<License>(d->m_internals, createRequest(url));
     return job;
@@ -413,6 +885,10 @@ ListJob< License >* Provider::requestLicenses()
 
 ListJob< Distribution >* Provider::requestDistributions()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/distributions" ) );
     ListJob<Distribution> *job = new ListJob<Distribution>(d->m_internals, createRequest(url));
     return job;
@@ -420,6 +896,10 @@ ListJob< Distribution >* Provider::requestDistributions()
 
 ListJob< HomePageType >* Provider::requestHomePageTypes()
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/homepages" ) );
     ListJob<HomePageType> *job = new ListJob<HomePageType>(d->m_internals, createRequest(url));
     return job;
@@ -437,6 +917,10 @@ ListJob<Content>* Provider::searchContentsByPerson(const Category::List& categor
 
 ListJob<Content>* Provider::searchContents(const Category::List& categories, const QString& person, const Distribution::List& distributions, const License::List& licenses, const QString& search, SortMode sortMode, uint page, uint pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/data" ) );
 
     QStringList categoryIds;
@@ -491,6 +975,10 @@ ListJob<Content>* Provider::searchContents(const Category::List& categories, con
 
 ItemJob<Content>* Provider::requestContent(const QString& id)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/data/" ) + id );
     ItemJob<Content> *job = new ItemJob<Content>(d->m_internals, createRequest(url));
     return job;
@@ -498,7 +986,7 @@ ItemJob<Content>* Provider::requestContent(const QString& id)
 
 ItemPostJob<Content>* Provider::addNewContent(const Category& category, const Content& cont)
 {
-    if (!category.isValid()) {
+    if (!isValid() || !category.isValid()) {
         return 0;
     }
 
@@ -516,6 +1004,10 @@ ItemPostJob<Content>* Provider::addNewContent(const Category& category, const Co
 
 ItemPostJob<Content>* Provider::editContent(const Category& updatedCategory, const QString& contentId, const Content& updatedContent)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     // FIXME I get a server error message here, though the name of the item is changed
     QUrl url = createUrl(QLatin1String( "content/edit/" ) + contentId);
     StringMap pars(updatedContent.attributes());
@@ -542,6 +1034,10 @@ PostJob* Provider::setDownloadFile(const QString& contentId, QIODevice* payload)
 
 PostJob* Provider::deleteContent(const QString& contentId)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "content/delete/" ) + contentId);
     PostFileData postRequest(url);
     postRequest.addArgument(QLatin1String( "contentid" ), contentId);
@@ -550,15 +1046,23 @@ PostJob* Provider::deleteContent(const QString& contentId)
 
 PostJob* Provider::setDownloadFile(const QString& contentId, const QString& fileName, const QByteArray& payload)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "content/uploaddownload/" ) + contentId);
     PostFileData postRequest(url);
     // FIXME mime type
-    postRequest.addFile(fileName, payload, QLatin1String( "application/octet-stream" ));
+    postRequest.addFile(fileName, payload, QLatin1String( "application/octet-stream" ), QLatin1String("source"));
     return new PostJob(d->m_internals, postRequest.request(), postRequest.data());
 }
 
 PostJob* Provider::deleteDownloadFile(const QString& contentId)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "content/deletedownload/" ) + contentId);
     PostFileData postRequest(url);
     postRequest.addArgument(QLatin1String( "contentid" ), contentId);
@@ -567,6 +1071,10 @@ PostJob* Provider::deleteDownloadFile(const QString& contentId)
 
 PostJob* Provider::setPreviewImage(const QString& contentId, const QString& previewId, const QString& fileName, const QByteArray& image)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "content/uploadpreview/" ) + contentId + QLatin1Char( '/' ) + previewId);
 
     PostFileData postRequest(url);
@@ -580,6 +1088,10 @@ PostJob* Provider::setPreviewImage(const QString& contentId, const QString& prev
 
 PostJob* Provider::deletePreviewImage(const QString& contentId, const QString& previewId)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "content/deletepreview/" ) + contentId + QLatin1Char( '/' ) + previewId);
     PostFileData postRequest(url);
     postRequest.addArgument(QLatin1String( "contentid" ), contentId);
@@ -589,6 +1101,10 @@ PostJob* Provider::deletePreviewImage(const QString& contentId, const QString& p
 
 PostJob* Provider::voteForContent(const QString& contentId, bool positiveVote)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "vote" ), positiveVote ? QLatin1String( "good" ) : QLatin1String( "bad" ));
     qDebug() << "vote: " << positiveVote;
@@ -597,8 +1113,16 @@ PostJob* Provider::voteForContent(const QString& contentId, bool positiveVote)
 
 PostJob* Provider::voteForContent(const QString& contentId, uint rating)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     // according to OCS API, the rating is 0..100
-    Q_ASSERT(rating <= 100);
+    if (rating > 100) {
+      qWarning() << "Rating cannot be superior to 100, fallback to 100." ;
+      rating = 100 ;
+    }
+
     StringMap postParameters;
     postParameters.insert(QLatin1String( "vote" ), QString::number(rating));
     qDebug() << "vote: " << QString::number(rating);
@@ -607,6 +1131,10 @@ PostJob* Provider::voteForContent(const QString& contentId, uint rating)
 
 PostJob* Provider::becomeFan(const QString& contentId)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "fan/add/" ) + contentId);
     PostFileData postRequest(url);
     postRequest.addArgument(QLatin1String( "contentid" ), contentId);
@@ -615,6 +1143,10 @@ PostJob* Provider::becomeFan(const QString& contentId)
 
 ListJob<Person>* Provider::requestFans(const QString& contentId, uint page, uint pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "fan/data/" ) + contentId );
     url.addQueryItem( QLatin1String( "contentid" ), contentId );
     url.addQueryItem( QLatin1String( "page" ), QString::number(page) );
@@ -625,6 +1157,10 @@ ListJob<Person>* Provider::requestFans(const QString& contentId, uint page, uint
 
 ItemJob<DownloadItem>* Provider::downloadLink(const QString& contentId, const QString& itemId)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "content/download/" ) + contentId + QLatin1Char( '/' ) + itemId );
     ItemJob<DownloadItem> *job = new ItemJob<DownloadItem>(d->m_internals, createRequest(url));
     return job;
@@ -632,6 +1168,10 @@ ItemJob<DownloadItem>* Provider::downloadLink(const QString& contentId, const QS
 
 ItemJob<KnowledgeBaseEntry>* Provider::requestKnowledgeBaseEntry(const QString& id)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "knowledgebase/data/" ) + id );
     ItemJob<KnowledgeBaseEntry> *job = new ItemJob<KnowledgeBaseEntry>(d->m_internals, createRequest(url));
     return job;
@@ -639,6 +1179,10 @@ ItemJob<KnowledgeBaseEntry>* Provider::requestKnowledgeBaseEntry(const QString&
 
 ListJob<KnowledgeBaseEntry>* Provider::searchKnowledgeBase(const Content& content, const QString& search, Provider::SortMode sortMode, int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl( QLatin1String( "knowledgebase/data" ) );
     if (content.isValid()) {
         url.addQueryItem(QLatin1String( "content" ), content.id());
@@ -674,12 +1218,20 @@ ListJob<KnowledgeBaseEntry>* Provider::searchKnowledgeBase(const Content& conten
 
 ItemJob<Event>* Provider::requestEvent(const QString& id)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     ItemJob<Event>* job = new ItemJob<Event>(d->m_internals, createRequest(QLatin1String( "event/data/" ) + id));
     return job;
 }
 
 ListJob<Event>* Provider::requestEvent(const QString& country, const QString& search, const QDate& startAt, Provider::SortMode mode, int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "event/data" ));
 
     if (!search.isEmpty()) {
@@ -716,6 +1268,10 @@ ListJob<Event>* Provider::requestEvent(const QString& country, const QString& se
 
 ListJob<Comment>* Provider::requestComments(const Comment::Type commentType, const QString& id, const QString& id2, int page, int pageSize)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QString commentTypeString;
     commentTypeString = Comment::commentTypeToString(commentType);
     if (commentTypeString.isEmpty()) {
@@ -733,6 +1289,10 @@ ListJob<Comment>* Provider::requestComments(const Comment::Type commentType, con
 
 ItemPostJob<Comment>* Provider::addNewComment(const Comment::Type commentType, const QString& id, const QString& id2, const QString& parentId, const QString &subject, const QString& message)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QString commentTypeString;
     commentTypeString = Comment::commentTypeToString(commentType);
     if (commentTypeString.isEmpty()) {
@@ -753,7 +1313,7 @@ ItemPostJob<Comment>* Provider::addNewComment(const Comment::Type commentType, c
 
 PostJob* Provider::voteForComment(const QString & id, uint rating)
 {
-    if (rating > 100) {
+    if (!isValid() || (rating > 100)) {
         return 0;
     }
 
@@ -766,6 +1326,10 @@ PostJob* Provider::voteForComment(const QString & id, uint rating)
 
 PostJob* Provider::setPrivateData(const QString& app, const QString& key, const QString& value)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     QUrl url = createUrl(QLatin1String( "privatedata/setattribute/" ) + app + QLatin1String( "/" ) + key);
     PostFileData postRequest(url);
 
@@ -776,6 +1340,10 @@ PostJob* Provider::setPrivateData(const QString& app, const QString& key, const
 
 ItemJob<PrivateData>* Provider::requestPrivateData(const QString& app, const QString& key)
 {
+    if (!isValid()) {
+        return 0;
+    }
+
     ItemJob<PrivateData>* job = new ItemJob<PrivateData>(d->m_internals, createRequest(QLatin1String( "privatedata/getattribute/" ) + app + QLatin1String( "/" ) + key));
     return job;
 }
@@ -793,7 +1361,7 @@ QUrl Provider::createUrl(const QString& path)
 QNetworkRequest Provider::createRequest(const QUrl& url)
 {
     QNetworkRequest request(url);
-
+    qDebug() << "OCS Request:" << url;
     if (!d->m_credentialsUserName.isEmpty()) {
         QString concatenated = d->m_credentialsUserName + QLatin1Char( ':' ) + d->m_credentialsPassword;
         QByteArray data = concatenated.toLocal8Bit().toBase64();
